@@ -2,11 +2,16 @@
 
 from km3io._definitions.mc_header import data as mc_header
 
-from km3io._definitions.trigger import data as trigger
+from km3io._definitions.daqdatatypes import data as daqdatatypes
 from km3io._definitions.fitparameters import data as fitparameters
 from km3io._definitions.reconstruction import data as reconstruction
+from km3io._definitions.root import data as root
+from km3io._definitions.trigger import data as trigger
 from km3io._definitions.w2list_genhen import data as w2list_genhen
 from km3io._definitions.w2list_gseagen import data as w2list_gseagen
+from km3io._definitions.trkmembers import data as trkmembers
+from km3io._definitions.applications import data as applications
+from km3io._definitions.pmt_status import data as pmt_status
 
 
 class AttrDict(dict):
@@ -17,6 +22,8 @@ class AttrDict(dict):
         self.__dict__ = self
 
 
+daqdatatypes = AttrDict(daqdatatypes)
+root = AttrDict(root)
 trigger = AttrDict(trigger)
 fitparameters = AttrDict(fitparameters)
 reconstruction = AttrDict(reconstruction)
@@ -28,3 +35,5 @@ fitparameters_idx = {v: k for k, v in fitparameters.items()}
 reconstruction_idx = {v: k for k, v in reconstruction.items()}
 w2list_genhen_idx = {v: k for k, v in w2list_genhen.items()}
 w2list_gseagen_idx = {v: k for k, v in w2list_gseagen.items()}
+pmt_status_idx = {v: k for k, v in pmt_status.items()}
+trkmembers_idx = {v: k for k, v in trkmembers.items()}
