@@ -32,6 +32,13 @@ class OfflineReader(EventReader):
             "channel_id": "hits.channel_id",
             "dom_id": "hits.dom_id",
             "t": "hits.t",
+            "tdc": "hits.tdc",
+            "pos_x": "hits.pos.x",
+            "pos_y": "hits.pos.y",
+            "pos_z": "hits.pos.z",
+            "dir_x": "hits.dir.x",
+            "dir_y": "hits.dir.y",
+            "dir_z": "hits.dir.z",
             "tot": "hits.tot",
             "trig": "hits.trig",  # non-zero if the hit is a triggered hit
         },
@@ -72,8 +79,8 @@ class OfflineReader(EventReader):
             "E": "mc_trks.E",
             "t": "mc_trks.t",
             "len": "mc_trks.len",
-            # "status": "mc_trks.status",  # TODO: check this
-            # "mother_id": "mc_trks.mother_id",  # TODO: check this
+            "status": "mc_trks.status",
+            "mother_id": "mc_trks.mother_id",
             "pdgid": "mc_trks.type",
             "hit_ids": "mc_trks.hit_ids",
             "usr": "mc_trks.usr",  # TODO: trouble with uproot4
@@ -108,7 +115,10 @@ class Header:
             n_fields = len(fields)
 
             if n_values == 1 and n_fields == 0:
-                self._data[attribute] = to_num(values[0])
+                entry = to_num(values[0])
+                self._data[attribute] = entry
+                if attribute.isidentifier():
+                    setattr(self, attribute, entry)
                 continue
 
             n_max = max(n_values, n_fields)
@@ -118,21 +128,22 @@ class Header:
             if not values:
                 continue
 
-            entry = {f: to_num(v) for (f, v) in zip(fields, values)}
-            try:
-                self._data[attribute] = namedtuple(attribute, fields)(**entry)
-            except ValueError:
-                self._data[attribute] = [to_num(v) for v in values]
+            cls_name = attribute if attribute.isidentifier() else "HeaderEntry"
+            entry = namedtuple(cls_name, fields)(*[to_num(v) for v in values])
 
-        for attribute, value in self._data.items():
-            try:
-                setattr(self, attribute, value)
-            except ValueError:
+            self._data[attribute] = entry
+
+            if attribute.isidentifier():
+                setattr(self, attribute, entry)
+            else:
                 log.warning(
                     f"Invalid attribute name for header entry '{attribute}'"
                     ", access only as dictionary key."
                 )
 
+    def __dir__(self):
+        return list(self.keys())
+
     def __str__(self):
         lines = ["MC Header:"]
         keys = set(mc_header.keys())
@@ -145,3 +156,12 @@ class Header:
 
     def __getitem__(self, key):
         return self._data[key]
+
+    def keys(self):
+        return self._data.keys()
+
+    def items(self):
+        return self._data.items()
+
+    def values(self):
+        return self._data.values()
